# wehyconfig
A simple configuration reader for TOML configuration files.

## Usage

- A single function: `read_config()`
- Pass it a configuration file (TOML) and optionally a section within the file. Returns a dictionary.
- Pass it a folder with configuration files (TOML) and it will return a dictionary of all the files.

## Documentation

[GitHub Pages Site](https://weehooey.github.io/wehyconfig)
